@@ -21,11 +21,14 @@ from liquid.stream import TokenStream
 from liquid.parse import get_parser
 
 from liquid import ast
+
 from liquid import loaders
 
 from liquid.exceptions import Error
 from liquid.exceptions import lookup_warning
 
+from . import LRUCache
+
 
 # pylint: disable=too-many-instance-attributes
 class Environment:
@@ -82,8 +85,6 @@ class Environment:
         self.mode = tolerance
 
         # Template cache
-        from liquid.utils import LRUCache
-
         self.cache = LRUCache(300)
 
         from liquid import builtin
